searchNodes=[{"doc":"Module for interfacing with the RPLidar A1/A2/A3 family of 360-degree LiDAR sensors. The RPLidar module is a GenServer that handles communication to and from the LiDAR device via a UART connection and an optional GPIO for motor control. Once connected and started, this process will send messages to the parent process (or a designated process) the decoded data received from the sensor. Basic Usage Once the RPLidar process is started, calling enable_motor will start the motor spinning and calling start_scan will start to receive and decode the packets from the sensor. The calling process (or a PID passed to the start_link function) will start to receive :lidar_packet messages as each one is received from the sensor. These packets contain the decoded information for each sensed point in the format {:lidar_packet, angle, range, quality, received_at} : angle - angle in degrees clockwise that the sensor was pointing when the point was sensed range - range measurement at the given angle in millimeters quality - quality measure of the laser return where 0 is no return and 255 is a full laser return received_at - the value of System.monotonic_time() when the packet was received def init ( _ ) do { :ok , pid } = RPLidar . start_link ( uart_device : &quot;ttyS0&quot; , motor_enable_pin : 18 ) :ok = RPLidar . enable_motor ( pid ) :ok = RPLidar . start_scan ( pid ) # ... end def handle_info ( { :lidar_packet , angle , range , quality , received_at } , state ) do # ... { :noreply , state } end To convert from angle and range to (x,y) coordinates (in meters): r = angle * Math . pi ( ) / 180.0 d = range / 1000 x = :math . sin ( r ) * d y = :math . cos ( r ) * d","ref":"RPLidar.html","title":"RPLidar","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"RPLidar.html#child_spec/1","title":"RPLidar.child_spec/1","type":"function"},{"doc":"Disables the motor.","ref":"RPLidar.html#disable_motor/1","title":"RPLidar.disable_motor/1","type":"function"},{"doc":"Enable the motor (sets the GPIO selected with the motor_enable_pin option to HIGH, which starts the motor spinning. Note that the datasheet for the RPLidar A1 requires the motor enable pin to be set to the VIN voltage of the motor. In cases where you are supplying, a voltage separate from the voltage of the GPIO pins of your device, you will have to enable the motor in a different way.","ref":"RPLidar.html#enable_motor/1","title":"RPLidar.enable_motor/1","type":"function"},{"doc":"After start_scan/1 is called, calling this function will force the device to send measurements without waiting for the motor to reach a threshold RPM.","ref":"RPLidar.html#force_scan/1","title":"RPLidar.force_scan/1","type":"function"},{"doc":"Polls the device for hardware and firmware info","ref":"RPLidar.html#get_info/1","title":"RPLidar.get_info/1","type":"function"},{"doc":"Resets the device.","ref":"RPLidar.html#reset/1","title":"RPLidar.reset/1","type":"function"},{"doc":"Starts the RPLidar process. Options uart_device - UART port to which the LiDAR is connected motor_enable_pin - GPIO pin for controlling the motor on the LiDAR sensor filter - if set to true , points with range of 0.0 or a quailty of 0 will be dropped before sending to the receiving process. (default: false ) parent - the PID to send points to (default: self() )","ref":"RPLidar.html#start_link/1","title":"RPLidar.start_link/1","type":"function"},{"doc":"Signals the device to start sending measurements. Note: Using the normal scan command, the device won't send any measurements until the sensor motor reaches a minimum RPM. Therefore if you call enable_motor/1 after or just before calling start_scan /1, there may be a delay before data is received by the parent process. To start sending measurements immediately regardless of motor speed, call force_scan/1 after calling start_scan/1 .","ref":"RPLidar.html#start_scan/1","title":"RPLidar.start_scan/1","type":"function"},{"doc":"Signals the device to stop sending measurements.","ref":"RPLidar.html#stop_scan/1","title":"RPLidar.stop_scan/1","type":"function"},{"doc":"Internal module containing functions for decoding messages received from the RPLidar device.","ref":"RPLidar.Comm.html","title":"RPLidar.Comm","type":"module"},{"doc":"","ref":"RPLidar.Comm.html#decode_get_info/1","title":"RPLidar.Comm.decode_get_info/1","type":"function"},{"doc":"","ref":"RPLidar.Comm.html#decode_scan/1","title":"RPLidar.Comm.decode_scan/1","type":"function"},{"doc":"","ref":"RPLidar.Comm.html#decode_scan/2","title":"RPLidar.Comm.decode_scan/2","type":"function"},{"doc":"","ref":"RPLidar.Comm.html#t:info/0","title":"RPLidar.Comm.info/0","type":"type"},{"doc":"The RPLidar.Frame struct contains a resultant frame produced by the RPLidar.Framer process. Its contents are a list of points and the start and finish timestamps (as returned from System.monotonic_time/0 ). Each member of the points list is a tuple containing the original point data as well as the converted Cartesian coordinates ( x and y ) calculated by the Framer process. angle - original angle from the raw point (in degrees) range - original range from the raw point (in millimeters) x and y - calculated Cartesian coordinates scaled by the scale options passed to the Framer (scaled to meters in the code above)","ref":"RPLidar.Frame.html","title":"RPLidar.Frame","type":"module"},{"doc":"","ref":"RPLidar.Frame.html#new/3","title":"RPLidar.Frame.new/3","type":"function"},{"doc":"","ref":"RPLidar.Frame.html#t:point/0","title":"RPLidar.Frame.point/0","type":"type"},{"doc":"","ref":"RPLidar.Frame.html#t:t/0","title":"RPLidar.Frame.t/0","type":"type"},{"doc":"The RPLidar.Framer module provides a process that can receive individual points and accumulate them into RPLidar.Frame s that represent a single 360-degree rotation of the sensor. These frames are much more useful for certain operations that require a &quot;snapshot&quot; of the ranges to objects around the sensor. Usage In order to use RPLidar.Framer , start a Framer process and hand its PID to the RPLidar.start_link/1 function. The Framer process will then receive sensor measurements and will send a :lidar_frame message with a RPLidar.Frame struct for each completed 360-degree scan. def init ( _ ) do { :ok , framer } = RPLidar.Framer . start_link ( scale : 0.001 , quality_threshold : 80 ) { :ok , pid } = RPLidar . start_link ( uart_device : &quot;ttyS0&quot; , motor_enable_pin : 18 , parent : framer , filter : true ) :ok = RPLidar . enable_motor ( pid ) :ok = RPLidar . start_scan ( pid ) # ... end def handle_info ( { :lidar_frame , % RPLidar.Frame { } = frame } , state ) do # ... { :noreply , state } end The RPLidar.Frame struct contains the points as a parameter points . Each point is a tuple {angle, range, x, y} containnig: angle - original angle from the raw point (in degrees) range - original range from the raw point (in millimeters) x and y - calculated Cartesian coordinates scaled by the scale options passed to the Framer (scaled to meters in the code above)","ref":"RPLidar.Framer.html","title":"RPLidar.Framer","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"RPLidar.Framer.html#child_spec/1","title":"RPLidar.Framer.child_spec/1","type":"function"},{"doc":"Starts a RPLidar.Framer process. Options scale - Scale factor to use when converting from millimeter range to Cartesian coordinates. For example, if set to 0.001, Cartesian coordinates will be returned in meters (default: 1.0) quality_threshold - Any point with a quality less than the given number will be ignored in the frame (default: 1) parent - the PID to send completed frames to (default: self() )","ref":"RPLidar.Framer.html#start_link/1","title":"RPLidar.Framer.start_link/1","type":"function"}]